@@ -4,19 +4,19 @@ use warnings;
 
 {
     no strict "vars";
-    $VERSION = "0.04";
+    $VERSION = "0.05";
 }
 
 use Acme::CPANAuthors::Register (
-	BBCIFL	    => 'BBC, Interactive Factual & Learning',
-	BBCPKENT	=> 'P Kent (BBC)',
-	BBCSIMONF	=> 'Simon Flack (BBC)',
-	BLACKSTAR	=> 'BlackStar',
-	CASTLE	    => 'Peter Goode/Castle Links Ltd',
-	FOTANGO	    => 'Fotango Ltd',
-	GMGRD	    => 'Guardian Media Group Regional Digital',
-	PROFERO	    => 'Profero Ltd.',
-	DOTTK	    => 'Dot TK Limited',
+    BBCIFL      => 'BBC, Interactive Factual & Learning',
+    BBCPKENT    => 'P Kent (BBC)',
+    BBCSIMONF   => 'Simon Flack (BBC)',
+    BLACKSTAR   => 'BlackStar',
+    CASTLE      => 'Peter Goode/Castle Links Ltd',
+    FOTANGO     => 'Fotango Ltd',
+    GMGRD       => 'Guardian Media Group Regional Digital',
+    PROFERO     => 'Profero Ltd.',
+    DOTTK       => 'Dot TK Limited',
 );
 
 q<
@@ -69,10 +69,6 @@ England, Wales, Scotland or Northern Ireland.
 
 L<Acme::CPANAuthors> - Main class to manipulate this one
 
-=head1 AUTHOR
-
-Barbie C<< <barbie at cpan.org> >>
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -107,11 +103,16 @@ Thanks to Kenichi Ishigaki for writing C<Acme::CPANAuthors>, and Sébastien
 Aperghis-Tramoni for writing C<Acme::CPANAuthors::French> on which I based
 this release.
 
+=head1 AUTHOR
+
+  Barbie, <barbie@cpan.org>
+  for Miss Barbell Productions <http://www.missbarbell.co.uk>.
+
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2010 Barbie for Miss Barbell Productions.
+  Copyright 2009-2012 Barbie for Miss Barbell Productions.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+  This module is free software; you can redistribute it and/or
+  modify it under the Artistic License 2.0.
 
 =cut
